import json

from browser import document, window
from json import dumps, loads

def on_click_on_analytic_target_element(event, manually_called: bool = False):
    # get currentTarget element
    target = event.currentTarget
    # check if data event has to collected by manual function call
    if not manually_called:
        if target.getAttribute('data-event-manual'):
            if target.getAttribute('data-event-manual') == 'True':
                return event

    # check vendor of interest in this event
    try:
        vendors: list = target.getAttribute('data-event-vendors').split('&')
    except Exception as e:
        print('error in base.py: ', e)
        vendors = []
        pass

    # process AA first
    if 'adobe_analytics' in vendors:
        vendor =  'adobe_analytics'
        page_name = window.AAPageData.name
        # attribute data-event-dict will always be there
        # data event dict also carry item_name
        data_event_dict = loads(target.getAttribute('data-event-dict-aa'))
        item_name = data_event_dict['item_name']
        # remove item_name from dict
        data_event_dict.pop('item_name')
        data_dict = data_event_dict
        # call event collector
        window.eventCollector(vendor, page_name, item_name, data_dict)

    # return event finally
    return event


def bind_analytic_listener_on_targets(unbind=False):
    # make on_click_on_analytic_target_element globally available
    window.on_click_on_analytic_target_element = on_click_on_analytic_target_element
    targets = document.select('[data-event-vendors]')
    # bind/unbind event function on every target
    for target in targets:
        if not unbind:
            target.bind("click", on_click_on_analytic_target_element)
        else:
            target.unbind("click", on_click_on_analytic_target_element)

    # run data check
    try:
        if window.AASetupData:
            if window.AASetupData['environment'] == 'qa':
                print('Adobe analytics environment is set to QA. Hence running tests.')
                # run checks on all the data-event-dict-aa values
                for target in targets:
                    try:
                        data_event_dict = loads(target.getAttribute('data-event-dict-aa'))
                        print(data_event_dict)
                    except json.JSONDecodeError:
                        print(f'Incorrect data-event-dict-aa value identified at: \n {target}')
                        pass
    except AttributeError:
        pass

bind_analytic_listener_on_targets()